package com.ningdatech.pmapi.performance.controller;

import javax.validation.Valid;

import com.ningdatech.pmapi.performance.manage.AppAppraisalManage;
import com.ningdatech.pmapi.performance.model.vo.*;
import org.springframework.web.bind.annotation.*;

import com.ningdatech.basic.model.PageVo;
import com.ningdatech.pmapi.performance.manage.ReAppraisalManage;
import com.ningdatech.pmapi.performance.model.dto.ProjectAppraisalDTO;
import com.ningdatech.pmapi.performance.model.req.PerformanceAppraisalListReq;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;

/**
 * ReAppraisalController
 * @return
 * @author CMM
 * @since 2023/08/10 8:54
 */
@RestController
@RequiredArgsConstructor
@Api(tags = "绩效评价-应用评价")
@RequestMapping("/api/v1/app-appraisal")
public class AppAppraisalController {

    private final AppAppraisalManage appAppraisalManage;

    @GetMapping("/list")
    @ApiOperation("当前复评用户的应用绩效评价计划列表")
    public PageVo<PerformanceAppraisalVO> list(PerformanceAppraisalListReq req) {
        return appAppraisalManage.list(req);
    }

    @GetMapping("/unEvaluate-list/{planId}/{reAppraisalGroupId}")
    @ApiOperation("当前绩效评价应用待评价列表")
    public PageVo<PerformanceAppraisalAppVO> pendingList(@PathVariable Long planId, @PathVariable Long reAppraisalGroupId, PerformanceAppraisalListReq req) {
        return appAppraisalManage.unEvaluateList(planId,reAppraisalGroupId,req);
    }

    @GetMapping("/evaluated-list/{planId}")
    @ApiOperation("当前绩效评价应用已评价列表")
    public PageVo<PerformanceAppraisalAppVO> evaluatedList(@PathVariable Long planId, @PathVariable Long reAppraisalGroupId, PerformanceAppraisalListReq req) {
        return appAppraisalManage.evaluatedList(planId,reAppraisalGroupId,req);
    }

    @GetMapping("/detail/{appId}")
    @ApiOperation("获取详情")
    public AppAppraisalIndexDetailVO detail(@PathVariable Long appId){
        return appAppraisalManage.detail(appId);
    }

    @PostMapping("/save")
    @ApiOperation("保存分数")
    public String saveAppraisal(@Valid @RequestBody ProjectAppraisalDTO param){
        return appAppraisalManage.saveAppraisal(param);
    }

}
